@@ -1,11 +1,17 @@
+# $File: //depot/OurNet-FuzzyIndex/ChatBot.pm $ $Author: autrijus $
+# $Revision: #5 $ $Change: 2149 $ $DateTime: 2001/10/18 21:43:43 $
+
 package OurNet::ChatBot;
 require 5.005;
 
-$OurNet::ChatBot::VERSION = '1.21';
+$OurNet::ChatBot::VERSION = '1.22';
 
 use strict;
 use OurNet::FuzzyIndex;
 
+use fields qw/botfile botname writable db nextone
+              avoid synonyms rndouts lastone/;
+
 =head1 NAME
 
 OurNet::ChatBot - Context-free interactive Q&A engine
@@ -27,37 +33,42 @@ OurNet::ChatBot - Context-free interactive Q&A engine
 
 =head1 DESCRIPTION
 
-The ChatBot module simulates a general-purpose, context-free,
-interactive Chat Bot using the OurBot(tm) engine. It reads
-the file stored in ChatBot/ directory, parses synonyms and
-random output settings, then return answers via the input()
-method.
+The B<OurNet::ChatBot> module simulates a general-purpose,
+context-free, interactive chatter-bot using the B<OurNet::FuzzyIndex>
+engine.  It reads the file stored in F<ChatBot/> directory, parses
+synonyms and random output settings, then return answers via the
+C<input()> method.
 
-The lastone property is used to return/set the id of the bot's
-last sentence. In conjunction of directly manipulating the CHUNKS
-array (which contains all possible return values for input()),
+This module require no reformatting of existing contents at all;
+it can automatically parse paragraphs and sentences, then convert
+the weighted data into a B<OurNet::FuzzyIndex> database. You can
+also specify additional parameters like keywords, weights and grammar
+at any time.
+
+The B<lastone> property is used to return/set the id of the bot's
+last sentence. In conjunction of directly manipulating the B<CHUNKS>
+array (which contains all possible return values for C<input()>),
 the front-end program could prevent duplicate responses.
 
 =head1 CAVEATS
 
 The nextone flag-property is implemented badly.
 
+=head1 METHODS
+
+=head2 new($class, $botname, $bot, [$writable])
+
+Constructor method; reads bot name, bot database file, and
+writable flag as arguments. Returns a B<OurNet::ChatBot>
+object.
+
 =cut
 
-# ---------------
-# Variable Fields
-# ---------------
-use fields qw/botfile botname writable db nextone
-              avoid synonyms rndouts lastone/;
-
-# ---------------------------------------
-# Subroutine new($botname,$bot,$writable)
-# ---------------------------------------
-# Input:  Bot name, BotDB, Writeable Flag
-# Output: A ChatBot object
-# ---------------------------------------
 sub new {
-    my $self = fields::new(shift);
+    my $class = shift;
+    my $self  = ($] > 5.00562) ? fields::new($class)
+                               : do { no strict 'refs';
+                                      bless [\%{"$class\::FIELDS"}], $class };
 
     $self->{botname}  = shift;
     $self->{botfile}  = shift
@@ -68,11 +79,12 @@ sub new {
     my $botdir = __FILE__;
     $botdir =~ s|\.pm$||;
 
-    eval { mkdir($botdir) unless -d $botdir };
+    eval { mkdir($botdir, 0666) unless -d $botdir };
 
     $botfile = (-e $self->{botfile})
-	? $self->{botfile} 
-	: "$botdir/$self->{botfile}";
+	? $self->{botfile}
+	: (-e "$botdir/$self->{botfile}") ? "$botdir/$self->{botfile}"
+	: $self->{botfile};
 
     die("OurNet::ChatBot cannot find the database: $self->{botfile}")
 	unless (-e $botfile or $self->{writable});
@@ -85,11 +97,12 @@ sub new {
     return $self;
 }
 
-# --------------------------------------
-# Subroutine addsyn($self, $skey, @syns)
-# --------------------------------------
-# Input:  Object, Word, Synonyms
-# --------------------------------------
+=head2 addsyn($self, $skey, @syns)
+
+Inserts new synonyms of the word C<$skey> into the bot database.
+
+=cut
+
 sub addsyn {
     my $self = shift;
     my $skey = shift;
@@ -97,33 +110,28 @@ sub addsyn {
     push(@{$self->{synonyms}}, $skey || ' ', join('|', @_));
 }
 
-# ------------------------------------------------
-# Subroutine addentry($self, $content, [$trigger])
-# ------------------------------------------------
-# Input:  Object, Text Chunk
-# ------------------------------------------------
-sub addentry {
-    my $self    = shift;
-    my $content = shift;
-    # my %words   = $self->{db}->parse_xs($content);
+=head2 addentry($self, $content, [$trigger])
 
+Inserts a response sentence to the chat-bot's corpus. The optional
+C<$trigger> variable indicates a B<cue> sentence to be used as
+index instead of C<$content>; this is useful in a Q & A context.
+
+=cut
+
+sub addentry {
+    my ($self, $content, $trigger) = @_;
     return unless $self->{writable};
 
-    # while (my $weight = shift) {
-        # %words = $self->{db}->parse_xs(shift, $weight, \%words);
-    # }
-
-    # $self->{db}->insert($content, \%words);
-    print "."; # print $content."\n";
-    $self->{db}->insert($content, shift || $content);
+    $self->{db}->insert($content, defined($trigger) ? $trigger : $content);
+    print ".";
 }
 
+=head2 sync($self)
+
+Writes back to the database file.
+
+=cut
 
-# -----------------------------------
-# Subroutine sync($self)
-# -----------------------------------
-# Syncronizes with the Database file.
-# -----------------------------------
 sub sync {
     my $self = shift;
 
@@ -134,12 +142,13 @@ sub sync {
     $self->{db}->sync;
 }
 
-# -------------------------------------
-# Subroutine input($self, $say, @avoid)
-# -------------------------------------
-# Input:  Object, Input, Chunks to skip
-# Output: ChatBot's feedback
-# -------------------------------------
+=head2 input($self, $say, [@avoid])
+
+Process the query sentence in C<$say>, and returns the chat-bot's
+response. The chunk IDs specified in C<@avoid> will not be used.
+
+=cut
+
 sub input {
     my $self    = shift;
     my $say     = shift;
@@ -168,11 +177,13 @@ sub input {
     return $self->{rndouts}[ int(rand() * ($#{$self->{rndouts}} + 1)) ];
 }
 
-# -----------------------------------------------------
-# Subroutine convert($self, $data)
-# -----------------------------------------------------
-# Converts Chatbot::Amber bot file entries to database.
-# -----------------------------------------------------
+=head2 convert($self, $data)
+
+Converts the legacy database in B<Chatbot::Amber> format to
+a database file.
+
+=cut
+
 sub convert {
     my $self = shift;
     my ($init, @chunks) = split(/\015?\012\s*--+\s*\015?\012/, shift);
@@ -193,7 +204,7 @@ sub convert {
         $def_val = $1;
     }
 
-    $self->sync();
+    $self->sync;
 
     foreach my $chunk (@chunks) {
         my @keywords;
@@ -225,7 +236,9 @@ Autrijus Tang E<lt>autrijus@autrijus.org>
 
 Copyright 2001 by Autrijus Tang E<lt>autrijus@autrijus.org>.
 
-All rights reserved.  You can redistribute and/or modify
-this module under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or 
+modify it under the same terms as Perl itself.
+
+See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
